@@ -121,6 +121,17 @@ hdp_repo_cfg = provisioning.Config(
     "HDP repo URL", "general", "cluster", priority=1, default_value="")
 hdp_utils_repo_cfg = provisioning.Config(
     "HDP-UTILS repo URL", "general", "cluster", priority=1, default_value="")
+autoconfigs_strategy = provisioning.Config(
+    "Auto-configuration strategy", 'general', 'cluster', priority=1,
+    config_type='dropdown',
+    default_value='NEVER_APPLY',
+    config_values=[(v, v) for v in [
+        'NEVER_APPLY', 'ALWAYS_APPLY', 'ONLY_STACK_DEFAULTS_APPLY',
+    ]],
+)
+ambari_pkg_install_timeout = provisioning.Config(
+    "Ambari Agent Package Install timeout", "general", "cluster",
+    priority=1, default_value="1800")
 
 
 def _get_service_name(service):
@@ -184,7 +195,8 @@ def load_configs(version):
     cfg_path = "plugins/ambari/resources/configs-%s.json" % version
     vanilla_cfg = jsonutils.loads(files.get_file_text(cfg_path))
     CONFIGS[version] = vanilla_cfg
-    sahara_cfg = [hdp_repo_cfg, hdp_utils_repo_cfg, use_base_repos_cfg]
+    sahara_cfg = [hdp_repo_cfg, hdp_utils_repo_cfg, use_base_repos_cfg,
+                  autoconfigs_strategy, ambari_pkg_install_timeout]
     for service, confs in vanilla_cfg.items():
         for k, v in confs.items():
             sahara_cfg.append(provisioning.Config(
@@ -213,6 +225,14 @@ def get_hdp_utils_repo_url(cluster):
     return _get_config_value(cluster, hdp_utils_repo_cfg)
 
 
+def get_auto_configuration_strategy(cluster):
+    return _get_config_value(cluster, autoconfigs_strategy)
+
+
+def get_ambari_pkg_install_timeout(cluster):
+    return _get_config_value(cluster, ambari_pkg_install_timeout)
+
+
 def _serialize_ambari_configs(configs):
     return list(map(lambda x: {x: configs[x]}, configs))
 
@@ -220,8 +240,9 @@ def _serialize_ambari_configs(configs):
 def _create_ambari_configs(sahara_configs, plugin_version):
     configs = {}
     for service, params in six.iteritems(sahara_configs):
-        if service == "general":
-            # General configs are designed for Sahara, not for the plugin
+        if service == "general" or service == "Kerberos":
+            # General and Kerberos configs are designed for Sahara, not for
+            # the plugin
             continue
         for k, v in six.iteritems(params):
             group = _get_config_group(service, k, plugin_version)
