@@ -51,6 +51,10 @@ repo_id_map = {
         "HDP": "HDP-2.5",
         "HDP-UTILS": "HDP-UTILS-1.1.0.21"
     },
+    "2.6": {
+        "HDP": "HDP-2.6",
+        "HDP-UTILS": "HDP-UTILS-1.1.0.22"
+    },
 }
 
 os_type_map = {
@@ -67,11 +71,21 @@ os_type_map = {
 def setup_ambari(cluster):
     LOG.debug("Set up Ambari management console")
     ambari = plugin_utils.get_instance(cluster, p_common.AMBARI_SERVER)
+    ambari_settings = ("agent.package.install.task.timeout=%s"
+                       % configs.get_ambari_pkg_install_timeout(cluster))
     with ambari.remote() as r:
         sudo = functools.partial(r.execute_command, run_as_root=True)
         sudo("rngd -r /dev/urandom -W 4096")
+        r.replace_remote_line("/etc/ambari-server/conf/ambari.properties",
+                              "agent.package.install.task.timeout=",
+                              ambari_settings)
         sudo("ambari-server setup -s -j"
              " `cut -f2 -d \"=\" /etc/profile.d/99-java.sh`", timeout=1800)
+        # the following change must be after ambari-setup, or it would be
+        # overwritten (probably because it's not part of the base set of
+        # keywords/values handled by ambari-setup).
+        r.append_to_file("/etc/ambari-server/conf/ambari.properties",
+                         "server.startup.web.timeout=180", run_as_root=True)
         redirect_file = "/tmp/%s" % uuidutils.generate_uuid()
         sudo("service ambari-server start >{rfile} && "
              "cat {rfile} && rm {rfile}".format(rfile=redirect_file))
